
History
=======

0.2.5 (2020-11-03)
------------------

* Fixed bug which prevented b[::2] from working.
* Switched to publishing via github action.

0.2.4 (2020-10-29)
------------------

* Changed curve test notation to match python slice notation.

0.2.3 (2020-10-29)
------------------

* Fixed bug in label anchors.

0.2.2 (2020-10-28)
------------------

* New draw method support variable text size and multiple simultaneous objects.
* Removed encode prefixes
* Added rotate to biflute

0.2.1 (2020-10-18)
------------------

* Re-engineered draw methods to support partial evaluation.
* Checking for useless-suppression.
* Added Cantor surface.
* Made flute and biflute b twists support expression notation.

0.2.0 (2020-04-17)
------------------

* Triangulations and laminations can now be drawn.
* Changed documented examples to show the new drawing methods.
* Fixed bug in which some twists occured in the wrong direction.
* Supporting and testing PyPy3.


0.1.0 (2020-02-28)
------------------

* Initial test release.
* Added flute, biflute, ladder and tree3 example surfaces.

